@@ -4,12 +4,14 @@ from .dipole import Dipole, DipoleThin
 from .drift import Drift
 from .quadrupole import Quadrupole, QuadrupoleThin
 from .sextupole import Sextupole, SextupoleThin
+from .kicker import KickerThin
 
 __all__ = [
     "CustomThin",
     "Dipole",
     "DipoleThin",
     "Drift",
+    "KickerThin",
     "Quadrupole",
     "QuadrupoleThin",
     "Sextupole",
